@@ -9,9 +9,8 @@
 
 #include "statuslist.h"
 
-#include <QString>
 #include "dialogbase.h"
-
+#include <QString>
 
 class QPlainTextEdit;
 class QAction;
@@ -20,16 +19,17 @@ class QLabel;
 class QLineEdit;
 class QSplitter;
 
-namespace KTextEditor {
-    class View;
-    class Document;
+namespace KTextEditor
+{
+class View;
+class Document;
 };
 
 // TODO: Filter in HgStatusList.
 
 /**
  * Implements dialog for Commit changes. User is presented with a list of
- * changes/added/removed files, their diffs, a TextEdit to enter 
+ * changes/added/removed files, their diffs, a TextEdit to enter
  * commit message, options to change/create/close branch and last 5 commit
  * messages.
  */
@@ -48,7 +48,7 @@ private Q_SLOTS:
     void slotItemSelectionChanged(const char status, const QString &fileName);
 
     /**
-     * Will enable 'Ok' button of dialog if some message text is available or 
+     * Will enable 'Ok' button of dialog if some message text is available or
      * disables it.
      */
     void slotMessageChanged();
@@ -68,33 +68,33 @@ private:
     void done(int r) override;
 
 private:
-    QString                      m_hgBaseDir;
+    QString m_hgBaseDir;
 
-    KTextEditor::Document       *m_commitMessage;
-    HgStatusList                *m_statusList;
+    KTextEditor::Document *m_commitMessage;
+    HgStatusList *m_statusList;
 
-    KTextEditor::View           *m_fileDiffView;
-    KTextEditor::Document       *m_fileDiffDoc;
+    KTextEditor::View *m_fileDiffView;
+    KTextEditor::Document *m_fileDiffDoc;
 
-    QPushButton                 *m_branchButton;
-    QPushButton                 *m_copyMessageButton;
+    QPushButton *m_branchButton;
+    QPushButton *m_copyMessageButton;
 
-    QAction                     *m_closeBranch;
-    QAction                     *m_newBranch;
-    QAction                     *m_useCurrentBranch;
-    QMenu                       *m_branchMenu;
-    QMenu                       *m_copyMessageMenu;
+    QAction *m_closeBranch;
+    QAction *m_newBranch;
+    QAction *m_useCurrentBranch;
+    QMenu *m_branchMenu;
+    QMenu *m_copyMessageMenu;
 
-    QSplitter                   *m_verticalSplitter; // Divides file list and editors
-    QSplitter                   *m_horizontalSplitter; // Divides commit editor and diff editor
+    QSplitter *m_verticalSplitter; // Divides file list and editors
+    QSplitter *m_horizontalSplitter; // Divides commit editor and diff editor
 
-    /** What will commit do with branch. 
+    /** What will commit do with branch.
      *
      * CloseBranch: Close the current branch
      * NewBranch  : Creates new branch for this commit
-     * NoChanges  : No changes to branch are made. 
+     * NoChanges  : No changes to branch are made.
      */
-    enum {CloseBranch, NewBranch, NoChanges} m_branchAction;
+    enum { CloseBranch, NewBranch, NoChanges } m_branchAction;
     QString m_newBranchName;
 };
 
@@ -103,23 +103,20 @@ private:
  */
 class NewBranchDialog : public QDialog
 {
-        Q_OBJECT
+    Q_OBJECT
 
-    public:
-        explicit NewBranchDialog(QWidget *parent = nullptr);
-        QString getBranchName() const;
+public:
+    explicit NewBranchDialog(QWidget *parent = nullptr);
+    QString getBranchName() const;
 
-    private Q_SLOTS:
-        void slotTextChanged(const QString &text);
-
-    private:
-        QLabel            *m_errorLabel;
-        QLineEdit         *m_branchNameInput;
-        QStringList        m_branchList;
-        QPushButton       *m_okButton;
+private Q_SLOTS:
+    void slotTextChanged(const QString &text);
 
+private:
+    QLabel *m_errorLabel;
+    QLineEdit *m_branchNameInput;
+    QStringList m_branchList;
+    QPushButton *m_okButton;
 };
 
 #endif // HGCOMMITDIALOG_H
-
-
