@@ -20,10 +20,8 @@ class CommitItemDelegate : public QItemDelegate
     Q_OBJECT
 public:
     explicit CommitItemDelegate(QObject *parent = nullptr);
-    void paint(QPainter *painter, const QStyleOptionViewItem &option,
-                  const QModelIndex &index) const override;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
-
 };
 
 #endif // COMMITITEMDELEGATE_H
